@@ -21,6 +21,7 @@ import re
 import os
 import sys
 
+import inspect
 import traceback
 
 from functools import wraps
@@ -42,28 +43,10 @@ from sure.six import string_types, text_type, PY3, get_function_code
 from sure.six.moves import reduce
 
 
-def safely_patch_dir(object_handler):
-    def custom_dir(self):
-        if not PY3:
-            try:
-                meta = list(self.__dict__)
-            except AttributeError:
-                meta = list(type(self).__dict__)
-
-            object_attrs = set(meta)
-        else:
-            object_attrs = set(super().__dir__())
-
-        sure_methods = set(POSITIVES + NEGATIVES)
-        return list(object_attrs.difference(sure_methods))
-
-    object_handler['__dir__'] = custom_dir
-
-
 if PY3:
     basestring = str
 
-version = '1.2.1'
+version = '1.2.3'
 
 
 not_here_error = \
@@ -426,6 +409,20 @@ NEGATIVES = [
     'shouldnot',
 ]
 
+class _IdentityAssertion(object):
+    def __init__(self, assertion_builder):
+        self._ab = assertion_builder
+
+    def __call__(self, other):
+        if self._ab.negative:
+            assert self._ab.obj is not other, "{0} should not be the same object as {1}, but it is".format(self._ab.obj, other)
+            return True
+        assert self._ab.obj is other, "{0} should be the same object as {1}, but it is not".format(self._ab.obj, other)
+        return True
+
+    def __getattr__(self, name):
+        return getattr(self._ab, name)
+
 
 class AssertionBuilder(object):
     def __init__(self, name=None, negative=False, obj=None):
@@ -469,19 +466,15 @@ class AssertionBuilder(object):
 
     @assertionproperty
     def be(self):
-        return self
+        return _IdentityAssertion(self)
 
-    @assertionproperty
-    def being(self):
-        return self
-
-    @assertionproperty
-    def not_being(self):
-        return self.should_not
+    being = be
 
     @assertionproperty
     def not_be(self):
-        return self.should_not
+        return _IdentityAssertion(self.should_not)
+
+    not_being = not_be
 
     @assertionproperty
     def not_have(self):
@@ -541,7 +534,7 @@ class AssertionBuilder(object):
             assert length > 0, (
                 u"expected `{0}` to not be empty".format(representation))
         else:
-            assert length is 0, (
+            assert length == 0, (
                 u"expected `{0}` to be empty but it has {1} items".format(representation, length))
 
         return True
@@ -623,6 +616,7 @@ class AssertionBuilder(object):
 
     eql = equal
     equals = equal
+    equal_to = equal
 
     @assertionmethod
     def an(self, klass):
@@ -788,6 +782,28 @@ class AssertionBuilder(object):
 
         return _that.raises(*args, **kw)
 
+    @assertionproperty
+    def cool(self):
+        _that = AssertionHelper(self.obj,
+                     with_args=self._callable_args,
+                     and_kwargs=self._callable_kw)
+        if self.negative:
+            try:
+                return _that.raises(Exception)
+            except AssertionError:
+                raise AssertionError('The callable `{0}` was supposed to not be cool and throw an exception, but it is too cool for that'.format(self.obj.__name__))
+
+        try:
+            self.obj(*self._callable_args, **self._callable_kw)
+        except Exception as e:
+            raise AssertionError('The callable `{2}` should be cool but threw {0}: {1}'.format(
+                e.__class__.__name__,
+                str(e),
+                self.obj.__name__
+            ))
+
+        return True
+
     @assertionmethod
     def return_value(self, value):
         return_value = self.obj(*self._callable_args, **self._callable_kw)
@@ -851,7 +867,7 @@ those = AssertionBuilder('those')
 expect = AssertionBuilder('expect')
 
 
-allows_new_syntax = sys.version.startswith('2.7') and not os.getenv('SURE_DISABLE_NEW_SYNTAX')
+allows_new_syntax = not os.getenv('SURE_DISABLE_NEW_SYNTAX')
 
 
 if is_cpython and allows_new_syntax:
@@ -903,7 +919,7 @@ if is_cpython and allows_new_syntax:
         return make_safe_property(method, name, prop)
 
     object_handler = patchable_builtin(object)
-    safely_patch_dir(object_handler)
+
     # None does not have a tp_dict associated to its PyObject, so this
     # is the only way we could make it work like we expected.
     none = patchable_builtin(None.__class__)
@@ -915,3 +931,18 @@ if is_cpython and allows_new_syntax:
     for name in NEGATIVES:
         object_handler[name] = negative_assertion(name)
         none[name] = negative_assertion(name, False)
+
+
+old_dir = dir
+
+
+if allows_new_syntax:
+    @wraps(builtins.dir)
+    def _new_dir(obj=None):
+        if obj is None:
+            frame = inspect.currentframe()
+            return sorted(frame.f_back.f_locals.keys())
+        else:
+            return sorted(set(old_dir(obj)).difference(POSITIVES + NEGATIVES))
+
+    builtins.dir = _new_dir
